@@ -26,15 +26,10 @@ def create_issue_query_dict(filename):
     series_string = " ".join(series_word_list).strip()
     series_string = quote_plus(series_string.encode("utf-8"))
     # If there isn't an issue number, let's assume it's "1".
-    if fnp.issue:
-        number = quote_plus(fnp.issue.encode("utf-8"))
-    else:
-        number = "1"
-    query_dict = {
+    number = quote_plus(fnp.issue.encode("utf-8")) if fnp.issue else "1"
+    return {
         "series": series_string,
         "volume": fnp.volume,
         "number": number,
         "year": fnp.year,
     }
-
-    return query_dict
